==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/dialogs/shifttimesdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "shifttimesdialog.h"
#include <timeedit.h>

#include <qgroupbox.h>
#include <qlayout.h>

#include <klocale.h>
#include <kcombobox.h>


using namespace SubtitleComposer;

ShiftTimesDialog::ShiftTimesDialog( QWidget* parent ):
	TargetableLinesActionDialog( i18n( "Shift Subtitles" ), parent )
{
	QGroupBox* groupBox = createGroupBox( i18n( "Shifting" ) );

	m_directionComboBox = new KComboBox( false, groupBox );
	m_directionComboBox->clear();
	m_directionComboBox->insertItem( i18n( "+ | Forwards" ) );
	m_directionComboBox->insertItem( i18n( "- | Backwards" ) );
	m_directionComboBox->setSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::Fixed );

	m_shiftTimeEdit = new TimeEdit( groupBox );

	QGridLayout* groupBoxLayout = createLayout( groupBox );
	groupBoxLayout->addWidget( m_directionComboBox, 0, 0 );
	groupBoxLayout->addWidget( m_shiftTimeEdit, 0, 1 );

	createLinesTargetGroupBox();
}

void ShiftTimesDialog::resetShiftTime()
{
	m_shiftTimeEdit->setValue( 0 );
}

int ShiftTimesDialog::shiftTimeMillis()
{
	return m_directionComboBox->currentItem() == 0 ? m_shiftTimeEdit->value() : - m_shiftTimeEdit->value();
}

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/main/dialogs/shifttimesdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "shifttimesdialog.h"
#include <timeedit.h>

#include <qbuttongroup.h>
#include <qlayout.h>

#include <klocale.h>
#include <kcombobox.h>


using namespace SubtitleComposer;

ShiftTimesDialog::ShiftTimesDialog( QWidget* parent ):
	ActionWithTargetDialog( i18n( "Shift Subtitles" ), parent )
{
	QButtonGroup* shiftingButtonGroup = createButtonGroup( i18n( "Shifting" ) );

	m_directionComboBox = new KComboBox( false, shiftingButtonGroup );
	m_directionComboBox->clear();
	m_directionComboBox->insertItem( i18n( "+ | Forwards" ) );
	m_directionComboBox->insertItem( i18n( "- | Backwards" ) );
	m_directionComboBox->setSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::Fixed );

	m_shiftTimeEdit = new TimeEdit( shiftingButtonGroup );


	createLinesTargetButtons();


	QGridLayout* shiftingLayout = createLayout( shiftingButtonGroup );
	shiftingLayout->addWidget( m_directionComboBox, 0, 0 );
	shiftingLayout->addWidget( m_shiftTimeEdit, 0, 1 );
}

void ShiftTimesDialog::resetShiftTime()
{
	m_shiftTimeEdit->setValue( 0 );
}

int ShiftTimesDialog::shiftTimeMillis() const
{
	return m_directionComboBox->currentItem() == 0 ? m_shiftTimeEdit->value() : - m_shiftTimeEdit->value();
}
